@@ -2,6 +2,11 @@
 
 
 
+
+def info():
+	print('this is v0.0.3 version')
+
+
 def ins(v):
     print("ins>>>")
     print('>dir:')
